vmdocker

package
v0.0.0-...-718a4e4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 16, 2026 License: MIT Imports: 28 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func SeedWorkspaceFromModule

func SeedWorkspaceFromModule(moduleID, workspace, archiveFormat string) error

SeedWorkspaceFromModule exposes seedWorkspaceFromModule for out-of-package tooling (the e2e driver). It resolves the module file relative to the current working directory, like the runtime spawn path.

func SeedWorkspaceProfileFromModule

func SeedWorkspaceProfileFromModule(moduleID, workspace, archiveFormat string) error

SeedWorkspaceProfileFromModule exposes seedWorkspaceProfileFromModule for out-of-package tooling (the e2e driver). It resolves the module file relative to the current working directory, like the runtime spawn path.

func Spawn

func Spawn(env vmmSchema.Env) (vm vmmSchema.Vm, err error)

Types

type VmDocker

type VmDocker struct {
	Env vmmSchema.Env
	// contains filtered or unexported fields
}

func New

func New(env vmmSchema.Env, nodeAddr string, tags []goarSchema.Tag) (*VmDocker, error)

todo: add cpu, mem

func (*VmDocker) Apply

func (v *VmDocker) Apply(from string, meta vmmSchema.Meta) vmmSchema.Result

func (*VmDocker) Checkpoint

func (v *VmDocker) Checkpoint() (string, error)

func (*VmDocker) Close

func (v *VmDocker) Close() error

func (*VmDocker) Restore

func (v *VmDocker) Restore(snapshot string) error

func (*VmDocker) Run

func (v *VmDocker) Run(cuAddr string, data []byte, tags []goarSchema.Tag) error

Directories

Path Synopsis
Package capability implements runtime Export/Import/Preview of an agent's public entries.
Package capability implements runtime Export/Import/Preview of an agent's public entries.
Package modulebuild builds a signed vmdocker module from a declarative profile: profile.toml -> standardized Dockerfile -> docker build/save -> container-tar module.
Package modulebuild builds a signed vmdocker module from a declarative profile: profile.toml -> standardized Dockerfile -> docker build/save -> container-tar module.

Jump to