Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func SeedWorkspaceFromModule ¶
SeedWorkspaceFromModule exposes seedWorkspaceFromModule for out-of-package tooling (the e2e driver). It resolves the module file relative to the current working directory, like the runtime spawn path.
func SeedWorkspaceProfileFromModule ¶
SeedWorkspaceProfileFromModule exposes seedWorkspaceProfileFromModule for out-of-package tooling (the e2e driver). It resolves the module file relative to the current working directory, like the runtime spawn path.
Types ¶
Directories
¶
| Path | Synopsis |
|---|---|
|
Package capability implements runtime Export/Import/Preview of an agent's public entries.
|
Package capability implements runtime Export/Import/Preview of an agent's public entries. |
|
Package modulebuild builds a signed vmdocker module from a declarative profile: profile.toml -> standardized Dockerfile -> docker build/save -> container-tar module.
|
Package modulebuild builds a signed vmdocker module from a declarative profile: profile.toml -> standardized Dockerfile -> docker build/save -> container-tar module. |
Click to show internal directories.
Click to hide internal directories.